@@ -54,8 +54,8 @@ find_external_resources <- function(input_file, encoding = 'UTF-8') {
 
   # ensure we're working with valid input
   ext <- tolower(xfun::file_ext(input_file))
-  if (!(ext %in% c("md", "rmd", "html", "htm", "r", "css"))) {
-    stop("Resource discovery is only supported for R Markdown files or HTML files.")
+  if (!(ext %in% c("md", "rmd", "qmd", "html", "htm", "r", "css"))) {
+    stop("Resource discovery is only supported for R Markdown, Quarto files or HTML (and CSS) files.")
   }
 
   if (!file.exists(input_file)) {
@@ -101,7 +101,7 @@ find_external_resources <- function(input_file, encoding = 'UTF-8') {
   }
 
   # run the main resource discovery appropriate to the file type
-  if (ext %in% c("md", "rmd")) {
+  if (ext %in% c("md", "rmd", "qmd")) {
     # discover R Markdown doc resources--scans the document itself as described
     # in comments above, renders as Markdown, and invokes HTML discovery
     # on the result
@@ -138,7 +138,7 @@ find_external_resources <- function(input_file, encoding = 'UTF-8') {
   # clean row names (they're not meaningful)
   rownames(discovered_resources) <- NULL
 
-  # convert paths from factors if necssary, and clean any redundant ./ leaders
+  # convert paths from factors if necessary, and clean any redundant ./ leaders
   discovered_resources$path <- as.character(discovered_resources$path)
   has_prefix <- grepl("^\\./", discovered_resources$path)
   discovered_resources$path[has_prefix] <- substring(discovered_resources$path[has_prefix], 3)
@@ -216,6 +216,13 @@ discover_rmd_resources <- function(rmd_file, discover_single_resource) {
         output_render_files <- unlist(output_format[c(
           'includes', 'pandoc_args', 'logo', 'reference_doc', 'reference_docx', 'template'
         )])
+        resolved_theme <- tryCatch(resolve_theme(output_format[["theme"]]), error = function(e) NULL)
+        # css needs to be copied for sass or bslib processing in formate rendering
+        needed <- if (is_bs_theme(resolved_theme)) TRUE else {
+          needs_sass(output_format[['css']])
+        }
+        output_render_files <- c(output_render_files, output_format[['css']][needed])
+
         lapply(output_render_files, discover_render_resource)
       }
     }
@@ -299,7 +306,7 @@ discover_rmd_resources <- function(rmd_file, discover_single_resource) {
   }
 
   # check for knitr child documents in R Markdown documents
-  if (tolower(xfun::file_ext(rmd_file)) == "rmd") {
+  if (tolower(xfun::file_ext(rmd_file)) %in% c("qmd", "rmd")) {
     chunk_lines <- gregexpr(knitr::all_patterns$md$chunk.begin, rmd_content, perl = TRUE)
     for (idx in seq_along(chunk_lines)) {
       chunk_line <- chunk_lines[idx][[1]]
@@ -332,7 +339,7 @@ discover_rmd_resources <- function(rmd_file, discover_single_resource) {
   # html_document to pick up dependencies
   output_format <- output_format_from_yaml_front_matter(rmd_content)
 
-  output_format_function <- eval(parse(text = output_format$name))
+  output_format_function <- eval(xfun::parse_only(output_format$name))
 
   override_output_format <- if (!is_pandoc_to_html(output_format_function()$pandoc)) "html_document"
 
@@ -351,7 +358,7 @@ discover_rmd_resources <- function(rmd_file, discover_single_resource) {
   discover_html_resources(html_file, discover_single_resource)
 
   # if this is an R Markdown file, purl the file to extract just the R code
-  if (tolower(xfun::file_ext(rmd_file)) == "rmd") {
+  if (tolower(xfun::file_ext(rmd_file)) %in% c("qmd", "rmd")) {
     r_file <- tempfile(fileext = ".R")
     # suppress possible try() errors https://github.com/rstudio/rmarkdown/issues/1247
     try_file <- tempfile()
