@@ -61,7 +61,7 @@ pandoc_convert <- function(input,
   on.exit(setwd(oldwd), add = TRUE)
 
   # input file and formats
-  args <- c(input)
+  args <- pandoc_path_arg(input)
   if (!is.null(to)) {
     if (to == 'html') to <- 'html4'
     if (to == 'pdf') to <- 'latex'
@@ -72,7 +72,7 @@ pandoc_convert <- function(input,
 
   # output file
   if (!is.null(output))
-    args <- c(args, "--output", output)
+    args <- c(args, "--output", pandoc_path_arg(output))
 
   # set pandoc stack size
   args <- prepend_pandoc_stack_size(args)
@@ -278,6 +278,14 @@ pandoc_metadata_arg <- function(name,
   c("--metadata", if (missing(value)) name else paste(name, "=", value, sep = ""))
 }
 
+#' @rdname pandoc_args
+#' @param file string. Path to a file
+#' @export
+pandoc_metadata_file_arg <- function(file) {
+
+  c("--metadata-file", pandoc_path_arg(file))
+}
+
 
 #' @rdname pandoc_args
 #' @export
@@ -385,6 +393,9 @@ pandoc_path_arg <- function(path, backslash = TRUE) {
 
   # remove redundant ./ prefix if present
   path <- sub('^[.]/', '', path)
+  # paths starting with - shouldn't be treated as command-line options (#2503)
+  i <- grepl('^-', path) & xfun::is_rel_path(path)
+  path[i] <- paste0('./', path[i])
 
   if (is_windows()) {
     i <- grep(' ', path)
