@@ -2,7 +2,7 @@
 #'
 #' Format for converting from R Markdown to a slidy presentation.
 #'
-#' See the \href{https://rmarkdown.rstudio.com/slidy_presentation_format.html}{online
+#' See the \href{https://bookdown.org/yihui/rmarkdown/slidy-presentation.html}{online
 #' documentation} for additional details on using the \code{slidy_presentation}
 #' format.
 #'
@@ -17,6 +17,7 @@
 #' @param font_adjustment Increase or decrease the default font size (e.g. -1 or
 #'   +1). You can also manually adjust the font size during the presentation
 #'   using the 'S' (smaller) and 'B' (bigger) keys.
+#' @param css One or more css files to include.
 #' @param ... Additional function arguments to pass to the base R Markdown HTML
 #'   output formatter \code{\link{html_document_base}}
 #' @return R Markdown output format to pass to \code{\link{render}}
@@ -31,7 +32,8 @@
 #' render("pres.Rmd", slidy_presentation(incremental = TRUE))
 #' }
 #' @export
-slidy_presentation <- function(incremental = FALSE,
+slidy_presentation <- function(number_sections = FALSE,
+                               incremental = FALSE,
                                slide_level = NULL,
                                duration = NULL,
                                footer = NULL,
@@ -42,9 +44,9 @@ slidy_presentation <- function(incremental = FALSE,
                                fig_caption = TRUE,
                                dev = 'png',
                                df_print = "default",
-                               smart = TRUE,
                                self_contained = TRUE,
                                highlight = "default",
+                               math_method = "default",
                                mathjax = "default",
                                template = "default",
                                css = NULL,
@@ -92,8 +94,6 @@ slidy_presentation <- function(incremental = FALSE,
     args <- c(args, pandoc_variable_arg("font-size-adjustment",
                                         font_adjustment))
 
-  md_extensions <- smart_extension(smart, md_extensions)
-
   # content includes
   args <- c(args, includes_to_pandoc_args(includes))
 
@@ -105,7 +105,7 @@ slidy_presentation <- function(incremental = FALSE,
 
   # additional css
   for (css_file in css)
-    args <- c(args, "--css", pandoc_path_arg(css_file))
+    args <- c(args, "--css", pandoc_path_arg(css_file, backslash = FALSE))
 
   # pre-processor for arguments that may depend on the name of the
   # the input file (e.g. ones that need to copy supporting files)
@@ -120,6 +120,7 @@ slidy_presentation <- function(incremental = FALSE,
     args <- c()
 
     # highlight
+    if (!is.null(highlight)) highlight <- resolve_highlight(highlight, highlighters())
     args <- c(args, pandoc_highlight_args(highlight, default = "pygments"))
 
     # return additional args
@@ -129,15 +130,19 @@ slidy_presentation <- function(incremental = FALSE,
   # return format
   output_format(
     knitr = knitr_options_html(fig_width, fig_height, fig_retina, keep_md, dev),
-    pandoc = pandoc_options(to = "slidy",
-                            from = from_rmarkdown(fig_caption, md_extensions),
-                            args = args),
+    pandoc = pandoc_options(
+      to = "slidy",
+      from = from_rmarkdown(fig_caption, md_extensions),
+      args = args,
+      lua_filters = if (number_sections) pkg_file_lua("number-sections.lua")
+    ),
     keep_md = keep_md,
     clean_supporting = self_contained,
     df_print = df_print,
     pre_processor = pre_processor,
-    base_format = html_document_base(smart = smart, lib_dir = lib_dir,
+    base_format = html_document_base(lib_dir = lib_dir,
                                      self_contained = self_contained,
+                                     math_method = math_method,
                                      mathjax = mathjax,
                                      bootstrap_compatible = TRUE,
                                      pandoc_args = pandoc_args,
